﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using LeanCloud;

namespace ui.login
{
    public class Create : MonoBehaviour
    {
        public InputField emailInput;
        public InputField pwInput;

        public Button createBtn;
        public Button returnBtn;

        public Text msgText;

        public Action<string> createedCallback;
        public Action returnCallback;

        private List<Behaviour> _lockableComponents;

        private void Awake()
        {
            _lockableComponents = new List<Behaviour>();
            _lockableComponents.Add(emailInput);
            _lockableComponents.Add(pwInput);
            _lockableComponents.Add(createBtn);
            _lockableComponents.Add(returnBtn);

            msgText.text = "";

            createBtn.onClick.AddListener(() =>
            {
                if (emailInput.text.Length > 0 && pwInput.text.Length > 0)
                {
                    _ = _startCreateAsync();
                }
            });

            returnBtn.onClick.AddListener(() =>
            {
                returnCallback?.Invoke();
            });
        }

        // Start is called before the first frame update
        void Start()
        {

        }

        // Update is called once per frame
        void Update()
        {

        }

        private async System.Threading.Tasks.Task _startCreateAsync()
        {
            _setLock(true);
            msgText.text = "";

            var user = new AVUser();
            user.Username = emailInput.text;
            user.Password = pwInput.text;
            user.Email = emailInput.text;

            try
            {
                await user.SignUpAsync();

                _setLock(false);

                createedCallback?.Invoke(user.Username);
            }
            catch (AVException e)
            {
                msgText.text = "Error : " + e.Code;

                _setLock(false);
            }
        }

        private void _setLock(bool b)
        {
            foreach (var c in _lockableComponents) c.enabled = !b;
        }
    }
}