﻿using LeanCloud;
using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

namespace ui.login
{
    public class Login : MonoBehaviour
    {
        public InputField emailInput;
        public InputField pwInput;

        public Button loginBtn;
        public Button createBtn;

        public Text msgText;

        public Action loginCallback;
        public Action createCallback;

        private List<Behaviour> _lockableComponents;

        private void Awake()
        {
            _lockableComponents = new List<Behaviour>();
            _lockableComponents.Add(emailInput);
            _lockableComponents.Add(pwInput);
            _lockableComponents.Add(loginBtn);
            _lockableComponents.Add(createBtn);

            msgText.text = "";

            emailInput.text = "a@b.c";
            pwInput.text = "a";

            loginBtn.onClick.AddListener(() => {
                if (emailInput.text.Length > 0 && pwInput.text.Length > 0)
                {
                    _ = _startLoginAsync();
                }
            });

            createBtn.onClick.AddListener(() => {
                createCallback?.Invoke();
            });
        }

        // Start is called before the first frame update
        void Start()
        {

        }

        // Update is called once per frame
        void Update()
        {

        }

        private async System.Threading.Tasks.Task _startLoginAsync()
        {
            msgText.text = "";
            _setLock(true);

            try
            {
                var user = await AVUser.LogInByEmailAsync(emailInput.text, pwInput.text);

                _setLock(false);

                loginCallback?.Invoke();
            } catch (AVException e)
            {
                msgText.text = "Error : " + e.Code;

                _setLock(false);
            }
        }

        private void _setLock(bool b)
        {
            foreach (var c in _lockableComponents) c.enabled = !b;
        }
    }
}